@@ -1,8 +1,13 @@
-from pangea.exceptions import AuditException
+from pangea.exceptions import PangeaException
 
 from .models import EventEnvelope
 
 
+# Audit SDK Specific Exceptions
+class AuditException(PangeaException):
+    """Audit SDK specific exceptions"""
+
+
 class EventCorruption(AuditException):
     """Event verifications fails"""
 
